@@ -1,6 +1,7 @@
 package Scrappy::Plugin;
+
 BEGIN {
-  $Scrappy::Plugin::VERSION = '0.92111190';
+    $Scrappy::Plugin::VERSION = '0.921111901';
 }
 
 # load OO System
@@ -39,8 +40,9 @@ has plugins => (
           ->in(map {"$_/Scrappy/Plugin"} @INC);
 
         my %plugins =
-            map { $_ => 1 }
-                map { s/.*(Scrappy[\\\/]Plugin[\\\/].*\.pm)/$1/; $_ } @files; #uniquenes
+          map { $_ => 1 }
+          map { s/.*(Scrappy[\\\/]Plugin[\\\/].*\.pm)/$1/; $_ }
+          @files;    #uniquenes
 
         for my $plugin (keys %plugins) {
 
