@@ -2,8 +2,9 @@
 # Dist::Zilla: +PodWeaver
 
 package Scrappy::Scraper::Control;
+
 BEGIN {
-  $Scrappy::Scraper::Control::VERSION = '0.92111190';
+    $Scrappy::Scraper::Control::VERSION = '0.921111901';
 }
 
 # load OO System
@@ -12,20 +13,23 @@ use Moose;
 # load other libraries
 use URI;
 
-has 'allowed'    => (is => 'rw', isa => 'HashRef', default => sub { {} });
-has 'options'    => (is => 'ro', isa => 'HashRef',
-    'default'    => sub { { methods => [qw/GET PUT PUSH DELETE POST/] } });
+has 'allowed' => (is => 'rw', isa => 'HashRef', default => sub { {} });
+has 'options' => (
+    is        => 'ro',
+    isa       => 'HashRef',
+    'default' => sub { {methods => [qw/GET PUT PUSH DELETE POST/]} }
+);
 has 'restricted' => (is => 'rw', isa => 'HashRef', default => sub { {} });
 
 
 sub allow {
-    my  ($self, @domains) = @_;
-    my  $i = 0;
-    
+    my ($self, @domains) = @_;
+    my $i = 0;
+
     for (@domains) {
-        
-        $_ = URI->new($_)->host if $_ =~ /\:\/\//; # url to domain
-        
+
+        $_ = URI->new($_)->host if $_ =~ /\:\/\//;    # url to domain
+
         next unless $_;
         delete $self->restricted->{$_} if defined $self->restricted->{$_};
         $self->allowed->{$_} = $self->options;
@@ -36,12 +40,12 @@ sub allow {
 
 
 sub restrict {
-    my  ($self, @domains) = @_;
-    my  $i = 0;
+    my ($self, @domains) = @_;
+    my $i = 0;
     for (@domains) {
-        
-        $_ = URI->new($_)->host if $_ =~ /\:\/\//; # url to domain
-        
+
+        $_ = URI->new($_)->host if $_ =~ /\:\/\//;    # url to domain
+
         next unless $_;
         delete $self->allowed->{$_} if defined $self->allowed->{$_};
         $self->restricted->{$_} = $self->options;
@@ -52,10 +56,10 @@ sub restrict {
 
 
 sub is_allowed {
-    my  $self = shift;
-    my  $url = shift;
-        $url = URI->new($url)->host if $url =~ /\:\/\//; # url to domain
-    my  %options = @_;
+    my $self = shift;
+    my $url  = shift;
+    $url = URI->new($url)->host if $url =~ /\:\/\//;    # url to domain
+    my %options = @_;
 
     # empty domain not allowed
     return 0 unless $url;
@@ -82,6 +86,7 @@ sub is_allowed {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -90,7 +95,7 @@ Scrappy::Scraper::Control - Scrappy HTTP Request Constraints System
 
 =head1 VERSION
 
-version 0.92111190
+version 0.921111901
 
 =head1 SYNOPSIS
 
